/*
 * Copyright 2016-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE file in the root directory of this source tree.
 *
 */

/* eslint camelcase: ["error", {properties: "never"}] */
/* jshint node: true, devel: true */

'use strict';

const crypto = require('crypto');
const config = require('config');
const express = require('express');
const request = require('request');
const bodyParser = require('body-parser');

const app = express();
app.set('port', process.env.PORT || 5000);
app.set('view engine', 'ejs');
app.use(bodyParser.json({verify: verifyRequestSignature}));
app.use(express.static('public'));

let quickReplyPayload = null;
/*
 * Be sure to setup your config values before running this code. You can
 * set them using environment variables or modifying the config file in /config.
 *
 */

// App Secret can be retrieved from the App Dashboard
const APP_SECRET = (process.env.MESSENGER_APP_SECRET) ?
    process.env.MESSENGER_APP_SECRET :
    config.get('appSecret');

// Arbitrary value used to validate a webhook
const VALIDATION_TOKEN = (process.env.MESSENGER_VALIDATION_TOKEN) ?
    (process.env.MESSENGER_VALIDATION_TOKEN) :
    config.get('validationToken');

// Generate a page access token for your page from the App Dashboard
const PAGE_ACCESS_TOKEN = (process.env.MESSENGER_PAGE_ACCESS_TOKEN) ?
    (process.env.MESSENGER_PAGE_ACCESS_TOKEN) :
    config.get('pageAccessToken');

// URL where the app is running (include protocol). Used to point to scripts and
// assets located at this address.
const SERVER_URL = (process.env.SERVER_URL) ?
    (process.env.SERVER_URL) :
    config.get('serverURL');

const GOOGLE_API_KEY = (process.env.GOOGLE_API_KEY) ?
    (process.env.GOOGLE_API_KEY) :
    config.get('googleAPIkey');

if (!(APP_SECRET && VALIDATION_TOKEN && PAGE_ACCESS_TOKEN && SERVER_URL)) {
  console.error('Missing config values');
}

// Index
app.get('/', (req, res) => {
  res.send('hello world i am a secret bot');
});

/*
 * Use your own validation token. Check that the token used in the Webhook
 * setup is the same token used here.
 *
 */
app.get('/webhook', (req, res) => {
  if (req.query['hub.mode'] === 'subscribe' &&
        req.query['hub.verify_token'] === VALIDATION_TOKEN) {
    console.log('Validating webhook');
    res.status(200).send(req.query['hub.challenge']);
  } else {
    console.error('Failed validation. Make sure the validation tokens match.');
    res.sendStatus(403);
  }
});

/*
 * All callbacks for Messenger are POST-ed. They will be sent to the same
 * webhook. Be sure to subscribe your app to your page to receive callbacks
 * for your page.
 * https://developers.facebook.com/docs/messenger-platform/product-overview/setup#subscribe_app
 *
 */
app.post('/webhook', (req, res) => {
  const data = req.body;

    // Make sure this is a page subscription
  if (data.object === 'page') {
        // Iterate over each entry
        // There may be multiple if batched
    data.entry.forEach(pageEntry => {
			// Const pageID = pageEntry.id;
			// const timeOfEvent = pageEntry.time;

            // Iterate over each messaging event
      pageEntry.messaging.forEach(messagingEvent => {
        if (messagingEvent.optin) {
          receivedAuthentication(messagingEvent);
        } else if (messagingEvent.message) {
          receivedMessage(messagingEvent);
        } else if (messagingEvent.delivery) {
          receivedDeliveryConfirmation(messagingEvent);
        } else if (messagingEvent.postback) {
          receivedPostback(messagingEvent);
        } else if (messagingEvent.read) {
          receivedMessageRead(messagingEvent);
        } else if (messagingEvent.account_linking) {
          receivedAccountLink(messagingEvent);
        } else {
          console.log('Webhook received unknown messagingEvent: ', messagingEvent);
        }
      });
    });

        // Assume all went well.
        //
        // You must send back a 200, within 20 seconds, to let us know you've
        // successfully received the callback. Otherwise, the request will time out.
    res.sendStatus(200);
  }
});

/*
 * This path is used for account linking. The account linking call-to-action
 * (sendAccountLinking) is pointed to this URL.
 *
 */
app.get('/authorize', (req, res) => {
  const accountLinkingToken = req.query.account_linking_token;
  const redirectURI = req.query.redirect_uri;

    // Authorization Code should be generated per user by the developer. This will
    // be passed to the Account Linking callback.
  const authCode = 'ae948fa89f4ea89FaF89a348ZSdsa409dADS9asd4kjpv';

    // Redirect users to this URI on successful login
  const redirectURISuccess = redirectURI + '&authorization_code=' + authCode;

  res.render('authorize', {
    accountLinkingToken,
    redirectURI,
    redirectURISuccess
  });
});

/*
 * Verify that the callback came from Facebook. Using the App Secret from
 * the App Dashboard, we can verify the signature that is sent with each
 * callback in the x-hub-signature field, located in the header.
 *
 * https://developers.facebook.com/docs/graph-api/webhooks#setup
 *
 */
function verifyRequestSignature(req, res, buf) {
  if (!req.headers['x-hub-signature']) {
        // For testing, let's log an error. In production, you should throw an
        // error.
    console.error('Couldn\'t validate the signature.');
    return req.send(403);
  }
  const signature = req.headers['x-hub-signature'];
  const elements = signature.split('=');
	// Const method = elements[0];
  const signatureHash = elements[1];

  const expectedHash = crypto.createHmac('sha1', APP_SECRET)
            .update(buf)
            .digest('hex');

  if (signatureHash !== expectedHash) {
    throw new Error('Couldn\'t validate the request signature.');
  }
}

/*
 * Authorization Event
 *
 * The value for 'optin.ref' is defined in the entry point. For the "Send to
 * Messenger" plugin, it is the 'data-ref' field. Read more at
 * https://developers.facebook.com/docs/messenger-platform/webhook-reference/authentication
 *
 */
function receivedAuthentication(event) {
  const senderID = event.sender.id;
  const recipientID = event.recipient.id;
  const timeOfAuth = event.timestamp;

    // The 'ref' field is set in the 'Send to Messenger' plugin, in the 'data-ref'
    // The developer can set this to an arbitrary value to associate the
    // authentication callback with the 'Send to Messenger' click event. This is
    // a way to do account linking when the user clicks the 'Send to Messenger'
    // plugin.
  const passThroughParam = event.optin.ref;

  console.log('Received authentication for user %d and page %d with pass ' +
        'through param \'%s\' at %d', senderID, recipientID, passThroughParam,
        timeOfAuth);

    // When an authentication is received, we'll send a message back to the sender
    // to let them know it was successful.
  sendTextMessage(senderID, 'You\'re mine now!');
}

/*
 * Message Event
 *
 * This event is called when a message is sent to your page. The 'message'
 * object format can vary depending on the kind of message that was received.
 * Read more at https://developers.facebook.com/docs/messenger-platform/webhook-reference/message-received
 *
 * For this example, we're going to echo any text that we get. If we get some
 * special keywords ('button', 'generic', 'receipt'), then we'll send back
 * examples of those bubbles to illustrate the special message bubbles we've
 * created. If we receive a message with an attachment (image, video, audio),
 * then we'll simply confirm that we've received the attachment.
 *
 */
function receivedMessage(event) {
  const senderID = event.sender.id;
  const recipientID = event.recipient.id;
  const timeOfMessage = event.timestamp;
  const message = event.message;

  console.log('[SPRAVA PRIJATA]  Received message for user %d and page %d at %d with message:',
        senderID, recipientID, timeOfMessage);
  console.log(JSON.stringify(message));

  const isEcho = message.is_echo;
  const messageId = message.mid;
  const appId = message.app_id;
  const metadata = message.metadata;

    // You may get a text or attachment but not both
  const messageText = message.text;
  const messageAttachments = message.attachments;
  const quickReply = message.quick_reply;

  if (isEcho) {
        // Just logging message echoes to console
    console.log('Received echo for message %s and app %d with metadata %s',
            messageId, appId, metadata);
    return;
  } else if (quickReply) {
    quickReplyPayload = quickReply.payload;
    console.log('Quick reply for message %s with payload %s',
            messageId, quickReplyPayload);
    if (quickReplyPayload === 'poloha') {
      keywordSearch(senderID);
      return;
    } else if (quickReplyPayload === 'weather') {
      sendTextMessage(senderID, 'Počasie si vyhľadáš jednoducho. \n\nNapíš "počasie <HĽADANÉ MESTO>" a rád ti vyhľadám informácie. \n\nPre príklad: \n\npočasie Bratislava\n');
      return;
    }
    requestLocation(senderID);
    return;
  }

  if (messageText) {
    if (messageText.toLowerCase().includes('pocasie') || messageText.toLowerCase().includes('počasie')) {
      getWeather(senderID, messageText);
    } else {
            // If we receive a text message, check to see if it matches any special
            // keywords and send back the corresponding example. Otherwise, just echo
            // the text we received.
      switch (messageText.toLowerCase()) {
        case 'poloha':
          keywordSearch(senderID);
          break;

        default:
          start(senderID);
      }
    }
  } else if (messageAttachments) {
    if (messageAttachments[0].payload.coordinates) {
      console.log('[PP] Prijata poloha od uzivatela \nLAT: ' + messageAttachments[0].payload.coordinates.lat); // Gives lattitude
      console.log('LONG: ' + messageAttachments[0].payload.coordinates.long); // Gives longitude

      const poloha = [];
      poloha.push(messageAttachments[0].payload.coordinates.long, messageAttachments[0].payload.coordinates.lat);

      sendLocation(senderID, poloha, quickReplyPayload);
    } else {
      sendTextMessage(senderID, 'Prepáč, som ešte len vo vývoji a neviem si s poradiť so správami, ktoré obsahujú prílohu :(');
    }
  }
}

/*
 * Delivery Confirmation Event
 *
 * This event is sent to confirm the delivery of a message. Read more about
 * these fields at https://developers.facebook.com/docs/messenger-platform/webhook-reference/message-delivered
 *
 */
function receivedDeliveryConfirmation(event) {
  const delivery = event.delivery;
  const messageIDs = delivery.mids;
  const watermark = delivery.watermark;

  if (messageIDs) {
    messageIDs.forEach(messageID => {
      console.log('Received delivery confirmation for message ID: %s',
                messageID);
    });
  }

  console.log('All message before %d were delivered.', watermark);
}

/*
 * Postback Event
 *
 * This event is called when a postback is tapped on a Structured Message.
 * https://developers.facebook.com/docs/messenger-platform/webhook-reference/postback-received
 *
 */
function receivedPostback(event) {
  const senderID = event.sender.id;
  const recipientID = event.recipient.id;
  const timeOfPostback = event.timestamp;

    // The 'payload' param is a developer-defined field which is set in a postback
    // button for Structured Messages.

  const payload = event.postback.payload;

  console.log('Received postback for user %d and page %d with payload \'%s\' ' +
        'at %d', senderID, recipientID, payload, timeOfPostback);

    // When a postback is called, we'll send a message back to the sender to
    // let them know it was successful
  sendTextMessage(senderID, 'Postback called');
}

/*
 * Message Read Event
 *
 * This event is called when a previously-sent message has been read.
 * https://developers.facebook.com/docs/messenger-platform/webhook-reference/message-read
 *
 */
function receivedMessageRead(event) {
  // All messages before watermark (a timestamp) or sequence have been seen.
  const watermark = event.read.watermark;
  const sequenceNumber = event.read.seq;

  console.log('Received message read event for watermark %d and sequence ' +
        'number %d', watermark, sequenceNumber);
}

/*
 * Account Link Event
 *
 * This event is called when the Link Account or UnLink Account action has been
 * tapped.
 * https://developers.facebook.com/docs/messenger-platform/webhook-reference/account-linking
 *
 */
function receivedAccountLink(event) {
  const senderID = event.sender.id;
  const status = event.account_linking.status;
  const authCode = event.account_linking.authorization_code;

  console.log('[LINK] Received account link event with for user %d with status %s ' +
        'and auth code %s ', senderID, status, authCode);
}

function start(recipientId) {
  const messageData = {
    messaging_type: 'RESPONSE',
    recipient: {
      id: recipientId
    },
    message: {
      text: 'Ahoj, ja som BOT. Čo si praješ vyhľadať? Pre aktuálne počasie klikni na "Zistiť Počasie" a pre vyhľadanie barov a reštaurácií v tvojom okolí klikni na "Vyhľadať Podniky".',
      quick_replies: [{
        content_type: 'text',
        title: 'Zistiť počasie',
        payload: 'weather'
      },
      {
        content_type: 'text',
        title: 'Vyhľadať Podniky',
        payload: 'poloha'
      }
      ]
    }
  };
  callSendAPI(messageData);
}

function keywordSearch(recipientId) {
  const messageData = {
    messaging_type: 'RESPONSE',
    recipient: {
      id: recipientId
    },
    message: {
      text: 'Čo si praješ vyhľadať?',
      quick_replies: [{
        content_type: 'text',
        title: 'Pizza',
        payload: 'pizza'
      },
      {
        content_type: 'text',
        title: 'Cestoviny',
        payload: 'pasta'
      },
      {
        content_type: 'text',
        title: 'Bar/Podnik',
        payload: 'bar'
      }
      ]
    }
  };
  callSendAPI(messageData);
}

/*
*
* Prijatie polohy od uzivatela a praca s nou
*
*
 */
function sendLocation(recipientId, poloha, keyword) {
  const radius = 1000;
  const longitude = poloha[0];
  const lattitude = poloha[1];

  const reqUrl = 'https://maps.googleapis.com/maps/api/place/nearbysearch/json?location=' + lattitude + ',' + longitude + '&radius=' + radius + '&keyword=' + keyword + '&key=' + GOOGLE_API_KEY + '&libraries=places';
  console.log('URL is: ' + reqUrl);

  request({
    url: reqUrl,
    json: true,
    method: 'GET'
  }, (error, response, body) => {
    if (error) {
      console.log('Error sending message: ', error);
    } else if (response.body.status) {
      console.log('Status: ', response.body.status);
    }
    console.log(body);

        // Vytvorenie poli do ktorych sa budu zapisovat jednotlive miesta, ktore dostaneme z GOOGLE API
    const geometryLattitude = [];
    const	geometryLongitude = [];
    const	isOpen = [];
    const	name = [];
    const	rating = [];
    const	types = [];
    const	vicinity = [];
    const	photo = [];
    const	placeID = [];

        // PARSOVANIE a ZAPIS miest do poli
    let i = 0;
    for (i; i < body.results.length; i++) {
      if (typeof body.results[i].opening_hours !== 'undefined') {
        isOpen[i] = body.results[i].opening_hours.open_now;
      }

      geometryLattitude[i] = body.results[i].geometry.location.lat;
      geometryLongitude[i] = body.results[i].geometry.location.lng;
      name[i] = body.results[i].name;
      types[i] = JSON.stringify(body.results[i].types);
      rating[i] = body.results[i].rating;
      vicinity[i] = body.results[i].vicinity;
      photo[i] = JSON.stringify(body.results[i].photos);
      console.log('\n' + photo[i] + '\n');
      if (typeof body.results[i].photos !== 'undefined') {
        photo[i] = body.results[i].photos[0].photo_reference;
        console.log('\n' + photo[i] + '\n');
      }
      placeID[i] = body.results[i].place_id;

      console.log(
                        '\n       NAME: ' + name[i] +
                        '\n       Geometry Longitude: ' + geometryLongitude[i] +
                        '\n       Geometry Lattitude: ' + geometryLattitude[i] +
                        '\n       IS OPEN: ' + isOpen[i] +
                        '\n       RATING: ' + rating[i] +
                        '\n       VICINITY: ' + vicinity[i] +
                        '\n       TYPES: ' + types[i] +
                        '\n       PLACE ID: ' + placeID[i] +
                        '\n       Number of i: ' + i +
                        ' \n \nhttps://maps.googleapis.com/maps/api/place/photo?maxwidth=200&photoreference=' + photo[i] + '&key=' + GOOGLE_API_KEY + '\n'
                    );
    }

    if (i >= 3) {
      sendNearestPlaces(recipientId, name, geometryLattitude, geometryLongitude, isOpen, rating, vicinity, photo, placeID, i);
      console.log('[GOOGLE API] Bolo najdenych ' + i + ' vysledkov. Zavolal som sendNearestPlaces();');
    } else {
      sendTextMessage(recipientId, 'Prepáč, ale v tvojom okolí je len ' + i + ' dostupných reštaurácií. Pre zobrazenie zoznamu je potrebných aspoň 5 dostupných reštaurácií.\n\nAle neboj, ja sa časom naučím pracovať aj s menším počtom :)');
      console.log('[ODPOVED UZIVATELOVI] Uzivatelovi: %d :bola odoslana odpoved, nakolko pocet najdenych restauracii bol' + i, recipientId);
    }
  });
}

/*
* Send an List Template with Lattitude, Longitude. Nearest 5 places by user search
*
*/
function sendNearestPlaces(recipientId, name, geometryLattitude, geometryLongitude, isOpen, rating, vicinity, photo, placeID) {
  let i = 0;
  const messageData = {
    messaging_type: 'RESPONSE',
    recipient: {
      id: recipientId
    },
    message: {
      attachment: {
        type: 'template',
        payload: {
          template_type: 'list',
          top_element_style: 'large',
          elements: [
            {
              title: name[i],
              subtitle: 'Rating: ' + rating[i] + '\nOpen now: ' + isOpen[i] + '\nAddress: ' + vicinity[i],
              image_url: 'https://maps.googleapis.com/maps/api/place/photo?maxwidth=300&photoreference=' + photo[i] + '&key=' + GOOGLE_API_KEY,
              default_action: {
                type: 'web_url',
                url: 'https://www.google.com/maps/search/?api=1&query=' + geometryLattitude[i] + ',' + geometryLongitude[i] + '&query_place_id=' + placeID[i],
                messenger_extensions: true,
                webview_height_ratio: 'tall',
                fallback_url: 'https://www.google.com/maps/search/?api=1&query=' + geometryLattitude[i] + ',' + geometryLongitude[i] + '&query_place_id=' + placeID[i]
              }
            },
            {
              title: name[++i],
              image_url: 'https://maps.googleapis.com/maps/api/place/photo?maxwidth=300&photoreference=' + photo[1] + '&key=' + GOOGLE_API_KEY,
              subtitle: 'Rating: ' + rating[i] + '\nOpen now: ' + isOpen[i] + '\nAddress: ' + vicinity[i],
              default_action: {
                type: 'web_url',
                url: 'https://www.google.com/maps/search/?api=1&query=' + geometryLattitude[i] + ',' + geometryLongitude[i] + '&query_place_id=' + placeID[i],
                messenger_extensions: true,
                webview_height_ratio: 'tall',
                fallback_url: 'https://www.google.com/maps/search/?api=1&query=' + geometryLattitude[i] + ',' + geometryLongitude[i] + '&query_place_id=' + placeID[i]
              }
            },
            {
              title: name[++i],
              image_url: 'https://maps.googleapis.com/maps/api/place/photo?maxwidth=300&photoreference=' + photo[i] + '&key=' + GOOGLE_API_KEY,
              subtitle: 'Rating: ' + rating[i] + '\nOpen now: ' + isOpen[i] + '\nAddress: ' + vicinity[i],
              default_action: {
                type: 'web_url',
                url: 'https://www.google.com/maps/search/?api=1&query=' + geometryLattitude[i] + ',' + geometryLongitude[i] + '&query_place_id=' + placeID[i],
                messenger_extensions: true,
                webview_height_ratio: 'tall',
                fallback_url: 'https://www.google.com/maps/search/?api=1&query=' + geometryLattitude[i] + ',' + geometryLongitude[i] + '&query_place_id=' + placeID[i]
              }
            },
            {
              title: name[++i],
              image_url: 'https://maps.googleapis.com/maps/api/place/photo?maxwidth=300&photoreference=' + photo[i] + '&key=' + GOOGLE_API_KEY,
              subtitle: 'Rating: ' + rating[i] + '\nOpen now: ' + isOpen[i] + '\nAddress: ' + vicinity[i],
              default_action: {
                type: 'web_url',
                url: 'https://www.google.com/maps/search/?api=1&query=' + geometryLattitude[i] + ',' + geometryLongitude[i] + '&query_place_id=' + placeID[i],
                messenger_extensions: true,
                webview_height_ratio: 'tall',
                fallback_url: 'https://www.google.com/maps/search/?api=1&query=' + geometryLattitude[i] + ',' + geometryLongitude[i] + '&query_place_id=' + placeID[i]
              }
            }
          ],
          buttons: [
            {
              title: 'Zobraziť ďalšie',
              type: 'postback',
              payload: 'show_next'
            }
          ]
        }
      }
    }
  };

  callSendAPI(messageData);
}

/*
 * Send a message with Quick Reply buttons.
 *
 */
function requestLocation(recipientId) {
  const messageData = {
    messaging_type: 'RESPONSE',
    recipient: {
      id: recipientId
    },
    message: {
      text: 'Prosím, pošli mi tvoju polohu.',
      quick_replies: [{
        content_type: 'location'
      }
      ]
    }
  };

  callSendAPI(messageData);
}

/*
 * Send a read receipt to indicate the message has been read
 *
 */
function sendReadReceipt(recipientId) {
  console.log('[SEEN] Sending a read receipt to mark message as seen');

  const messageData = {
    messaging_type: 'RESPONSE',
    recipient: {
      id: recipientId
    },
    sender_action: 'mark_seen'
  };

  callSendAPI(messageData);
}

/*
 * Turn typing indicator on
 *
 */
function sendTypingOn(recipientId) {
  console.log('Turning typing indicator on');

  const messageData = {
    messaging_type: 'RESPONSE',
    recipient: {
      id: recipientId
    },
    sender_action: 'typing_on'
  };

  callSendAPI(messageData);
}

/*
 * Turn typing indicator off
 *
 */
function sendTypingOff(recipientId) {
  console.log('Turning typing indicator off');

  const messageData = {
    messaging_type: 'RESPONSE',
    recipient: {
      id: recipientId
    },
    sender_action: 'typing_off'
  };

  callSendAPI(messageData);
}

/*
 * Send a message with the account linking call-to-action
 *
 *//*
function sendAccountLinking(recipientId) {
  const messageData = {
    recipient: {
      id: recipientId
    },
    message: {
      attachment: {
        type: 'template',
        payload: {
          template_type: 'button',
          text: 'Ahoj. Prosím, pripoj si svoj účet ku mne, aby sme boli kompatibilný.',
          buttons: [{
            type: 'account_link',
            url: SERVER_URL + '/authorize'
          }]
        }
      }
    }
  };

  callSendAPI(messageData);
}*/

function getWeather(sender, message) {
  const city = message.slice(8);
  const reqUrl = 'http://api.openweathermap.org/data/2.5/weather?q=' + city + '&lang=sk&units=metric&appid=8191bb08101b4f839084715178f5713d';
  console.log('URL is: ' + reqUrl);

  request({
    url: reqUrl,
    json: true,
    method: 'GET'

  }, (error, response, body) => {
    if (error) {
      console.log('Error sending message: ', error);
      return response.status(500);
    } else if (response.body.error) {
      console.log('Error: ', response.body.error);
      return response.status(500);
    } else if (body.cod === '404') {
      console.log('Error, city not found!\n');
      return sendTextMessage(sender, 'Prepac, zadane mesto nebolo najdene v databaze.');
    }
    console.log(body);
    const weather = body.main.temp;

    console.log(weather);
    sendTextMessage(sender, city + ': Momentálne je ' + body.weather[0].description + ', ' + weather + ' °C a bude fúkať vietor rýchlosťou ' + body.wind.speed + ' m/s. Na oblohe je ' + body.clouds.all + '% oblacnost.');
  });
}

/*
 * Call the Send API. The message data goes in the body. If successful, we'll
 * get the message id in a response
 *
 */
function callSendAPI(messageData) {
  request({
    uri: 'https://graph.facebook.com/v2.6/me/messages',
    qs: {access_token: PAGE_ACCESS_TOKEN},
    method: 'POST',
    json: messageData

  }, (error, response, body) => {
    if (!error && response.statusCode === 200) {
      const recipientId = body.recipient_id;
      const messageId = body.message_id;

      if (messageId) {
        console.log('[ODPOVED ODOSLANA] Successfully sent message with id %s to recipient %s',
                    messageId, recipientId);
      } else {
        console.log('Successfully called Send API for recipient %s',
                    recipientId);
      }
    } else {
      console.error('Failed calling Send API', response.statusCode, response.statusMessage, body.error);
    }
  });
}

function sendTextMessage(recipientId, messageText) {
  const messageData = {
    messaging_type: 'RESPONSE',
    recipient: {
      id: recipientId
    },
    message: {
      text: messageText
    }
  };

  callSendAPI(messageData);
}

// Start server
// Webhooks must be available via SSL with a certificate signed by a valid
// certificate authority.
app.listen(app.get('port'), () => {
  console.log('Node app is running on port', app.get('port'));
});

module.exports = app;
